/*
 * Licensed Materials - Property of IBM
 *
 * com.ibm.etools.c
 *
 *  Copyright IBM Corporation 2004. All Rights Reserved. 
 *
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */

package com.ibm.etools.c.importer;

/**
 * CSourceLocation represents a source location within a source file. It has 3
 * attributes: file name, row number and column number.
 */
public class CSourceLocation {

    public static final String copyright = "Licensed Material - Property of IBM\n com.ibm.etools.c\n(C) Copyright IBM Corp. 2004 - All Rights Reserved.\nUS Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp."; //$NON-NLS-1$

    private String _fileName;

    private int _row;

    private int _column;

    /**
     * Default constructor
     */
    public CSourceLocation() {
        _fileName = null;
        _row = _column = 0;
    }

    /**
     * Create a CSourceLocation object from a given file name
     */
    public CSourceLocation(String fileName) {
        _fileName = fileName;
        _row = _column = 0;
    }

    /**
     * Create a CSourceLocation object from a given file name, row number and
     * column number
     */
    public CSourceLocation(String fileName, int row, int column) {
        _fileName = fileName;
        _row = row;
        _column = column;
    }

    /**
     * Return the file name
     */
    public String getFileName() {
        return _fileName;
    }

    /**
     * Return the row number
     */
    public int getRow() {
        return _row;
    }

    /**
     * Return the column number
     */
    public int getColumn() {
        return _column;
    }

    /**
     * Set the file name
     */
    public void setFileName(String fileName) {
        _fileName = fileName;
    }

    /**
     * Set the row and column number
     */
    public void setRowColumn(int row, int column) {
        _row = row;
        _column = column;
    }

}