// ****************************************************************
//
//   IBM Confidential
//   OCO Source Materials
//   <<PART NUMBER - 5724-B75>>
//   (C) Copyright IBM Corp. 2001 - All Rights Reserved.
//   US Government Users Restricted Rights - Use, duplication or disclosure
//   restricted by GSA ADP Schedule Contract with IBM Corp.
//
// ****************************************************************

package com.ibm.etools.marshall.util;

import java.math.*;

public class MarshallPackedDecimalUtils
{
	private static final String copyright = "(c) Copyright IBM Corporation 2001.";


static public void marshallPackedDecimalIntoBuffer (BigDecimal value, byte[] buffer, int startingOffset, int size, boolean signed, int virtualDecimalPoint)
	throws IllegalArgumentException
{
	// Move the decimal point to the right
	value = value.movePointRight (virtualDecimalPoint);

	// Need to make a decision here as to whether the value can fit into a long (8 bytes)
	// or not and then marshall appropriately (ie. 32 bit or 64 bit)
	if (size < 10)
		marshallPackedDecimalIntoBuffer (value.longValue(), buffer, startingOffset, size, signed);
	else
	{
		char[] bdChars = (value.toString()).toCharArray();
		byte[] pdBytes = ConversionUtils.convertToPackedDecimal (bdChars, size, signed);
		System.arraycopy (pdBytes, 0, buffer, startingOffset, pdBytes.length);
	}

	return;
}

static public void marshallPackedDecimalIntoBuffer (BigInteger value, byte[] buffer, int startingOffset, int size, boolean signed)
	throws IllegalArgumentException
{
	BigDecimal bd = new BigDecimal(value);

	marshallPackedDecimalIntoBuffer (bd, buffer, startingOffset, size, signed, 0);

	return;
}

static public void marshallPackedDecimalIntoBuffer (double value, byte[] buffer, int startingOffset, int size, boolean signed, int virtualDecimalPoint)
	throws IllegalArgumentException
{
	BigDecimal bd = new BigDecimal(Double.toString(value));

	marshallPackedDecimalIntoBuffer (bd, buffer, startingOffset, size, signed, virtualDecimalPoint);

	return;
}

static public void marshallPackedDecimalIntoBuffer (float value, byte[] buffer, int startingOffset, int size, boolean signed, int virtualDecimalPoint)
	throws IllegalArgumentException
{
	BigDecimal bd = new BigDecimal(Float.toString(value));

	marshallPackedDecimalIntoBuffer (bd, buffer, startingOffset, size, signed, virtualDecimalPoint);

	return;
}

static public void marshallPackedDecimalIntoBuffer (long value, byte[] buffer, int startingOffset, int size, boolean signed)
	throws IllegalArgumentException
{
	byte[] pdBytes = ConversionUtils.convertToPackedDecimal (value, size, signed);
	System.arraycopy (pdBytes, 0, buffer, startingOffset, pdBytes.length);

	return;
}

static public byte unmarshallByteFromBuffer (byte[] buffer, int startingOffset, int size)
	throws IllegalArgumentException
{
	byte result = (byte)unmarshallLongFromBuffer (buffer, startingOffset, size);

	return (result);
}

static public short unmarshallShortFromBuffer (byte[] buffer, int startingOffset, int size)
	throws IllegalArgumentException
{
	short result = (short)unmarshallLongFromBuffer (buffer, startingOffset, size);

	return (result);
}

static public int unmarshallIntFromBuffer (byte[] buffer, int startingOffset, int size)
	throws IllegalArgumentException
{
	int result = (int)unmarshallLongFromBuffer (buffer, startingOffset, size);

	return (result);
}

static public long unmarshallLongFromBuffer (byte[] buffer, int startingOffset, int size)
	throws IllegalArgumentException
{
	long result = 0;
	byte[] pdBytes = new byte[size];
	System.arraycopy (buffer, startingOffset, pdBytes, 0, pdBytes.length);	

	result = ConversionUtils.convertPackedDecimalToBinary (pdBytes);

	return (result);
}

static public BigDecimal unmarshallBigDecimalFromBuffer (byte[] buffer, int startingOffset, int size, int virtualDecimalPoint)
	throws IllegalArgumentException
{
	BigDecimal bdRes = null;

	// Need to make a decision here as to whether the value can fit into a long (8 bytes)
	// or not and then marshall appropriately (ie. 32 bit or 64 bit)
	if (size < 10)
	{
		long result = unmarshallLongFromBuffer (buffer, startingOffset, size);

		// Create BigDecimal Result
		bdRes = new BigDecimal(Long.toString(result));
	}
	else
	{
		byte[] pdBytes = new byte[size];
		System.arraycopy (buffer, startingOffset, pdBytes, 0, pdBytes.length);	

		bdRes = ConversionUtils.convertPackedDecimalToBigDecimal (pdBytes);
	}

	// Move the decimal point left
	bdRes = bdRes.movePointLeft (virtualDecimalPoint);

	return (bdRes);
}

static public BigInteger unmarshallBigIntegerFromBuffer (byte[] buffer, int startingOffset, int size)
	throws IllegalArgumentException
{
	BigInteger result = (unmarshallBigDecimalFromBuffer (buffer, startingOffset, size, 0)).toBigInteger();

	return (result);
}

static public double unmarshallDoubleFromBuffer (byte[] buffer, int startingOffset, int size, int virtualDecimalPoint)
	throws IllegalArgumentException
{
	double result = (unmarshallBigDecimalFromBuffer (buffer, startingOffset, size, virtualDecimalPoint)).doubleValue();

	return (result);
}

static public float unmarshallFloatFromBuffer (byte[] buffer, int startingOffset, int size, int virtualDecimalPoint)
	throws IllegalArgumentException
{
	float result = (unmarshallBigDecimalFromBuffer (buffer, startingOffset, size, virtualDecimalPoint)).floatValue();

	return (result);
}

}